@@ -3,7 +3,7 @@ import socket
 from logging import debug, info, warning, error, critical
 
 
-def udp_to_amx(amx_ip, message, amx_rx_port=10002) -> None:
+def udp_to_amx(amx_ip,  amx_rx_port=10002, message='test') -> None:
     import sys
     from logging import debug, info, warning, error, critical
 
@@ -16,13 +16,14 @@ def udp_to_amx(amx_ip, message, amx_rx_port=10002) -> None:
 
     message = (f"{message}\r").encode()
     client = (amx_ip, amx_rx_port)
-    
     try:
         s.sendto(message, client)
         debug(f"sent {message} to {client}")
     except socket.error as e:
-        error(f'udptoamx udp_to_amx() client send {e}')
+        error(f'udptoamx udp_to_amx() client send socket: {e}')
         sys.exit()
+    except Exception as e:
+        error(f"djangmx udp_to_amx client send generic: {e}")
 
     try:
         s.close()
